@@ -2,10 +2,13 @@ from .loader import Loader
 from .extractor import Extractor
 from .transformer import Transformer
 from .orchestrator import Orchestrator
+from .types import EtlBase, dataset_group
 
 __all__ = [
     "Loader",
     "Extractor",
     "Transformer",
     "Orchestrator",
+    "EtlBase",
+    "dataset_group",
 ]
